pub fn dump_files<ObjectID: FsVerityHashValue>(
repo: &Repository<ObjectID>,
image_name: &str,
files: &Vec<PathBuf>,
backing_path_only: bool,
) -> Result<Vec<u8>>Expand description
Print file information from a composefs filesystem for the given paths
For each path in files, looks up the entry in the filesystem and either
outputs composefs dumpfile-format metadata or, when backing_path_only is
set, prints whether the file is stored inline or its object-relative path.
Directory paths have their contents listed.